pub struct SignedKeyAuthorization {
pub authorization: KeyAuthorization,
pub signature: PrimitiveSignature,
signer: OnceLock<Address>,
}Expand description
Signed key authorization that can be attached to a transaction.
Fields
Key authorization for provisioning access keys
signature: PrimitiveSignatureSignature authorizing this key (signed by root key)
signer: OnceLock<Address>Cached signer recovered from signature.
Excluded from encoding, equality, hashing, and arbitrary generation.
Implementations
Sourceimpl SignedKeyAuthorization
impl SignedKeyAuthorization
fn _alloy_rlp_payload_length(&self) -> usize
Sourceimpl SignedKeyAuthorization
impl SignedKeyAuthorization
Sourcepub fn new(
authorization: KeyAuthorization,
signature: PrimitiveSignature,
) -> Self
pub fn new( authorization: KeyAuthorization, signature: PrimitiveSignature, ) -> Self
Create a signed key authorization with an empty signer cache.
Sourcepub fn recover_signer(&self) -> Result<Address, RecoveryError>
pub fn recover_signer(&self) -> Result<Address, RecoveryError>
Recover the signer of the KeyAuthorization.
fn cache_signer(&self, signer: Address)
std only.Methods from Deref<Target = KeyAuthorization>
Sourcepub fn witness(&self) -> Option<B256>
pub fn witness(&self) -> Option<B256>
Returns this authorization’s TIP-1053 witness, if present.
Sourcepub fn signature_hash(&self) -> B256
pub fn signature_hash(&self) -> B256
Computes the authorization message hash for this key authorization.
Sourcepub fn has_periodic_limits(&self) -> bool
pub fn has_periodic_limits(&self) -> bool
Returns whether any token limit uses periodic reset semantics.
Sourcepub fn has_call_scopes(&self) -> bool
pub fn has_call_scopes(&self) -> bool
Returns whether this authorization carries explicit call-scope restrictions.
Sourcepub fn has_witness(&self) -> bool
pub fn has_witness(&self) -> bool
Returns whether this authorization carries a TIP-1053 witness field.
Sourcepub fn has_unlimited_spending(&self) -> bool
pub fn has_unlimited_spending(&self) -> bool
Returns whether this key has unlimited spending (limits is None)
Sourcepub fn never_expires(&self) -> bool
pub fn never_expires(&self) -> bool
Returns whether this key never expires (expiry is None)
Sourcepub fn is_legacy_compatible(&self) -> bool
pub fn is_legacy_compatible(&self) -> bool
Returns whether this authorization can be encoded with the legacy pre-T3 ABI.
Sourcepub fn validate_chain_id(
&self,
expected_chain_id: u64,
is_t1c: bool,
) -> Result<(), KeyAuthorizationChainIdError>
pub fn validate_chain_id( &self, expected_chain_id: u64, is_t1c: bool, ) -> Result<(), KeyAuthorizationChainIdError>
Validates that this key authorization’s chain_id is compatible with expected_chain_id.
- Post-T1C:
chain_idmust exactly match (wildcard0is no longer allowed). - Pre-T1C:
chain_id == 0is a wildcard (valid on any chain), otherwise must match.